@@ -1,7 +1,7 @@
 package App::ImageInfoUtils;
 
 our $DATE = '2019-06-09'; # DATE
-our $VERSION = '0.002'; # VERSION
+our $VERSION = '0.003'; # VERSION
 
 use 5.010001;
 use strict;
@@ -10,6 +10,12 @@ use warnings;
 
 our %SPEC;
 
+$SPEC{':package'} = {
+    v => 1.1,
+    summary => 'Utilities related to getting (metadata) information from '.
+        'images',
+};
+
 our %arg0_files = (
     files => {
         'x.name.is_plural' => 1,
@@ -167,7 +173,7 @@ sub image_orientation {
 }
 
 1;
-# ABSTRACT: Return exit code 0 if image is portrait
+# ABSTRACT: Utilities related to getting (metadata) information from images
 
 __END__
 
@@ -177,11 +183,11 @@ __END__
 
 =head1 NAME
 
-App::ImageInfoUtils - Return exit code 0 if image is portrait
+App::ImageInfoUtils - Utilities related to getting (metadata) information from images
 
 =head1 VERSION
 
-This document describes version 0.002 of App::ImageInfoUtils (from Perl distribution App-ImageInfoUtils), released on 2019-06-09.
+This document describes version 0.003 of App::ImageInfoUtils (from Perl distribution App-ImageInfoUtils), released on 2019-06-09.
 
 =head1 FUNCTIONS
 
